#include "boards.h"
#include "nrf_delay.h"
#include <stdbool.h>
#include <stdint.h>

#define MODE 0
#define PSEL 8
#define PORT 13
#define POLARITY 16
#define OUTINIT 20
#define PULL 2
#define DIR 0
#define INPUT 1
#define PULL 2
#define DRIVE 8
#define SENSE 16

int main(void) {

    /*    Button 1
    // DIR   = 0 --> input
    // PULL  = 3 --> Pull up on pin (is always high, but turns low when pressed)
    // DRIVE = 0 --> Standard '0', standard '1' (I think the current is standard, 0.5mA)
    // SENSE = 0 --> Sense is disabled                               NO--> Sense for high level (When this pin is high, then the DETECT signal will be set high)
    */
    
    NRF_P0->PIN_CNF[BUTTON_1] = (0x00 << DIR) |(0x03 << PULL) | (0x00 << DRIVE) | (0x00 << SENSE);


    /*  Configure button 1 to channel 0 as input to trigger event (n=1)
    // MODE     = 1    --> Event mode (pin specififed by PSEL is input and IN[n] event will occur when operation specified by POLARITY happens on pin)
    // PSEL     = 11   --> Button 1 is spefified as the input
    // POLARITY = 1    --> Generate IN[n] event when rising edge on pin.
    */

    NRF_GPIOTE->CONFIG[0] = (0x01 << MODE) | (BUTTON_1 << PSEL) | (0x02 << POLARITY);

    /* Configure LED2 to channel 1, and it will be triggered by a task
    // MODE     = 3    --> The GPIO specified by PSEL will be configured as an output and triggering the SET[n], CLR[n] or OUT[n] task will perform the operation specified by POLARITY on the pin. 
    // PSEL     = 14   --> Led 1 is specified as the output
    // POLARITY = 3    --> Toggle pin from OUT[n]
    // OUTINIY  = 1    --> Initial value of pin before task triggering is high 
    */

    NRF_GPIOTE->CONFIG[1] = (0x03 << MODE) | (LED_2 << PSEL) | (0x03 << POLARITY) | (0x01 << OUTINIT);

    //Enable Tasks & Events

    NRF_GPIOTE->INTENSET = (0x01 << 0x00) | (0x01 << 0x01);

    while (true) {
      //Remove comment below
      if (NRF_GPIOTE->EVENTS_IN[0] != 0) {

        //printf("\r Event happened\r\n");
        NRF_GPIOTE->TASKS_OUT[1] = 0x001;
        NRF_GPIOTE->EVENTS_IN[0] = 0;
      } else {
        NRF_GPIOTE->TASKS_OUT[1] = 0x000;
      }
    }
}
